@@ -458,8 +458,6 @@ add_rows_with_zero <- function(plotdata, mode="surv") {
                                         "n_boot", "surv"))
       }
     }
-    rownames(row_0) <- NULL
-    plotdata <- rbind(row_0, plotdata)
 
   } else if (length(levs_no_zero)!=0 & mode=="cif") {
     row_0 <- data.frame(time=0, group=levs_no_zero, cif=0)
@@ -477,10 +475,20 @@ add_rows_with_zero <- function(plotdata, mode="surv") {
                                         "n_boot", "cif"))
       }
     }
-    rownames(row_0) <- NULL
-    plotdata <- rbind(row_0, plotdata)
+  } else {
+    return(plotdata)
   }
 
+  # multiple imputation fix
+  if ("var_w" %in% colnames(plotdata)) {
+    row_0$var_w <- 0
+    row_0$var_b <- 0
+    row_0$var_t <- 0
+  }
+
+  rownames(row_0) <- NULL
+  plotdata <- rbind(row_0, plotdata)
+
   return(plotdata)
 }
 
@@ -557,7 +565,13 @@ max_observed_time <- function(mids, variable, ev_time, event, levs, cause,
   }
 
   # keep only events
-  event_dat <- mids$data[mids$data[, event]==cause,]
+  # NOTE: in crude methods, the curves are defined up to the last censoring time
+  #       per group, not only to the last event!
+  if (method %in% c("km", "aalen_johansen")) {
+    event_dat <- mids$data
+  } else {
+    event_dat <- mids$data[mids$data[, event]==cause,]
+  }
 
   if (method %in% group_specific_methods) {
     # calculate maximal observed time in each group
